@@ -29,8 +29,6 @@
 
 #include "nv-mm.h"
 
-#include <linux/version.h>
-
 static void __nv_drm_gem_nvkms_memory_free(struct nv_drm_gem_object *nv_gem)
 {
     struct nv_drm_device *nv_dev = nv_gem->nv_dev;
@@ -224,7 +222,7 @@ done:
 
 /* XXX Move these vma operations to os layer */
 
-static int __nv_drm_vma_fault(struct vm_area_struct *vma,
+static vm_fault_t __nv_drm_vma_fault(struct vm_area_struct *vma,
                               struct vm_fault *vmf)
 {
     unsigned long address = nv_page_fault_va(vmf);
@@ -232,7 +230,7 @@ static int __nv_drm_vma_fault(struct vm_area_struct *vma,
     struct nv_drm_gem_nvkms_memory *nv_nvkms_memory = to_nv_nvkms_memory(
         to_nv_gem_object(gem));
     unsigned long page_offset, pfn;
-    int ret = -EINVAL;
+    vm_fault_t ret;
 
     pfn = (unsigned long)(uintptr_t)nv_nvkms_memory->pPhysicalAddress;
     pfn >>= PAGE_SHIFT;
@@ -240,8 +238,7 @@ static int __nv_drm_vma_fault(struct vm_area_struct *vma,
     page_offset = vmf->pgoff - drm_vma_node_start(&gem->vma_node);
 
 #if defined(NV_VMF_INSERT_PFN_PRESENT)
-    (void)ret;
-    return vmf_insert_pfn(vma, address, pfn + page_offset);
+    ret = vmf_insert_pfn(vma, address, pfn + page_offset);
 #else
     ret = vm_insert_pfn(vma, address, pfn + page_offset);
 
@@ -252,16 +249,18 @@ static int __nv_drm_vma_fault(struct vm_area_struct *vma,
              * EBUSY indicates that another thread already handled
              * the faulted range.
              */
-            return VM_FAULT_NOPAGE;
+            ret = VM_FAULT_NOPAGE;
+            break;
         case -ENOMEM:
-            return VM_FAULT_OOM;
+            ret = VM_FAULT_OOM;
+            break;
         default:
             WARN_ONCE(1, "Unhandled error in %s: %d\n", __FUNCTION__, ret);
+            ret = VM_FAULT_SIGBUS;
             break;
     }
-
-    return VM_FAULT_SIGBUS;
 #endif
+    return ret;
 }
 
 /*
@@ -270,16 +269,12 @@ static int __nv_drm_vma_fault(struct vm_area_struct *vma,
  */
 
 #if defined(NV_VM_OPS_FAULT_REMOVED_VMA_ARG)
-#if LINUX_VERSION_CODE < KERNEL_VERSION(5, 1, 0)
-static int nv_drm_vma_fault(struct vm_fault *vmf)
-#else
 static vm_fault_t nv_drm_vma_fault(struct vm_fault *vmf)
-#endif
 {
     return __nv_drm_vma_fault(vmf->vma, vmf);
 }
 #else
-static int nv_drm_vma_fault(struct vm_area_struct *vma,
+static vm_fault_t nv_drm_vma_fault(struct vm_area_struct *vma,
                                 struct vm_fault *vmf)
 {
     return __nv_drm_vma_fault(vma, vmf);
